@@ -1,4 +1,5 @@
 use crate::deps::*;
+use crate::window::WindowRunMode;
 
 use std::cell::Cell;
 use std::collections::VecDeque;
@@ -561,9 +562,9 @@ mod imp {
 
             self.sidebar_stack
                 .set_visible_child(&self.find_sidebar.get());
-            self.find_sidebar.grab_focus();
             self.document_action_group
                 .change_action_state("show-sidebar", &true.into());
+            self.find_sidebar.grab_focus();
             self.set_action_enabled("find-next", true);
             self.set_action_enabled("find-previous", true);
         }
@@ -833,8 +834,9 @@ impl PpsDocumentView {
         document: &Document,
         metadata: Option<&papers_view::Metadata>,
         dest: Option<&LinkDest>,
+        mode: WindowRunMode,
     ) {
-        self.imp().open_document(document, metadata, dest);
+        self.imp().open_document(document, metadata, dest, mode);
     }
 
     pub fn reload_document(&self, document: Option<&Document>) {
